@@ -1,12 +1,6 @@
-/* LICENSE BEGIN
-    This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
+// Copyright © SixtyFPS GmbH <info@sixtyfps.io>
+// SPDX-License-Identifier: (GPL-3.0-only OR LicenseRef-SixtyFPS-commercial)
 
-    SPDX-License-Identifier: GPL-3.0-only
-    This file is also available under commercial licensing terms.
-    Please contact info@sixtyfps.io for more information.
-LICENSE END */
 /*!
 Implementation detail for the vtable crate
 */
@@ -479,7 +473,7 @@ pub fn vtable(_attr: TokenStream, item: TokenStream) -> TokenStream {
                 vtable_ctor.push(quote!(#ident: {
                     unsafe extern "C" fn #ident(_: &#vtable_name, ptr: *mut u8, layout: vtable::Layout) {
                         use ::core::convert::TryInto;
-                        ::std::alloc::dealloc(ptr, layout.try_into().unwrap())
+                        vtable::internal::dealloc(ptr, layout.try_into().unwrap())
                     }
                     #ident
                 },));
@@ -571,7 +565,7 @@ pub fn vtable(_attr: TokenStream, item: TokenStream) -> TokenStream {
             let generated_trait_assoc_const =
                 generated_trait_assoc_const.get_or_insert_with(|| ItemTrait {
                     attrs: Attribute::parse_outer.parse_str(&format!(
-                        "/** Trait containing the associated constant relative to the the trait {}.\n{} */",
+                        "/** Trait containing the associated constant relative to the trait {}.\n{} */",
                         trait_name, additional_doc
                     )).unwrap(),
                     ident: quote::format_ident!("{}Consts", trait_name),
@@ -705,7 +699,7 @@ and implements HasStaticVTable for it.
             #[allow(unused)]
             use super::*;
             use ::vtable::*;
-            use ::std::boxed::Box; // make sure `Box` was not overridden in super
+            use ::vtable::internal::*;
             #input
 
             impl #vtable_name {
